PathInterner

Struct PathInterner 

pub(crate) struct PathInterner {
    map: IndexSet<VfsPath, BuildHasherDefault<FxHasher>>,
}
Structure to map between VfsPath and FileId.

Fields

map: IndexSet<VfsPath, BuildHasherDefault<FxHasher>>

Implementations

Source

impl PathInterner

pub(crate) fn get(&self, path: &VfsPath) -> Option<FileId>

Get the id corresponding to path.

If path does not exists in self, returns None.

pub(crate) fn intern(&mut self, path: VfsPath) -> FileId

Insert path in self.

  • If path already exists in self, returns its associated id;
  • Else, returns a newly allocated id.
pub(crate) fn lookup(&self, id: FileId) -> &VfsPath

Returns the path corresponding to id.

Panics

Panics if id does not exists in self.